__version__ = "0.0.2"

"""
Changelog:
0.0.2: Change order of arguments- allows users to put they tests in more
    places, i.e.doesn't restrict to data/'type' anymore
0.0.1: Initial version. Probably buggy
"""
